@@ -5,16 +5,18 @@ import os
 import sys
 import zipfile
 
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 
 log = logging.getLogger(__name__)
-#log=logging
+# log=logging
 
 log.debug('version=' + __version__)
 
+
 class PatoolError(Exception):
     pass
 
+
 def check_patool():
     try:
         import patoolib
@@ -24,65 +26,67 @@ def check_patool():
         log.debug('patool was not found')
     return ok
 
+
 class Archive(object):
     '''
     :param backend: ``auto``, ``patool`` or ``zipfile``
-    :param filename: path to archive file       
+    :param filename: path to archive file
     '''
     def __init__(self, filename, backend='auto'):
         self.filename = path(filename).expand().abspath()
         self.backend = backend
-              
-    def extractall_patool(self, directory): 
+
+    def extractall_patool(self, directory):
         log.debug("starting backend patool")
         p = Proc([
                          'patool',
                          'extract',
                          self.filename,
                          '--outdir=' + directory,
-    #                     '--verbose',
+                 #                     '--verbose',
                          ]).call()
         if p.return_code:
             raise PatoolError("patool can not unpack\n" + str(p.stderr))
-            
-                         
-    def extractall_zipfile(self, directory): 
+
+    def extractall_zipfile(self, directory):
         log.debug("starting backend zipfile")
         zipfile.ZipFile(self.filename).extractall(directory)
-        
-    def extractall(self, directory, auto_create_dir=False): 
+
+    def extractall(self, directory, auto_create_dir=False):
         '''
         :param directory: directory to extract to
         :param auto_create_dir: auto create directory
-        '''       
-        log.debug("extracting %s into %s (backend=%s)" % (self.filename, directory, self.backend))
+        '''
+        log.debug("extracting %s into %s (backend=%s)" % (
+            self.filename, directory, self.backend))
         is_zipfile = zipfile.is_zipfile(self.filename)
         directory = path(directory).expand().abspath()
         if not self.filename.exists():
-            raise ValueError("archive file does not exist:" + str(self.filename))
+            raise ValueError(
+                "archive file does not exist:" + str(self.filename))
         if not directory.exists():
             if auto_create_dir:
                 directory.makedirs()
             else:
                 raise ValueError("directory does not exist:" + str(directory))
-            
+
         if self.backend == 'auto':
             if is_zipfile:
                 try:
                     self.extractall_zipfile(directory)
                 except AttributeError:
                     # py25
-                    self.extractall_patool(directory)                    
+                    self.extractall_patool(directory)
             elif check_patool():
                 self.extractall_patool(directory)
             else:
-                raise ValueError("no backend for archive file:" + str(self.filename))
-            
+                raise ValueError("no backend for archive file: %s (is patool installed?)" % str(self.filename))
+
         if self.backend == 'zipfile':
             if not is_zipfile:
                 raise ValueError("file is not zip file:" + str(self.filename))
             self.extractall_zipfile(directory)
-            
+
         if self.backend == 'patool':
             if check_patool():
                 self.extractall_patool(directory)
